@@ -14,7 +14,7 @@
  * limitations under the License.
  */
 
-/* $Id: Mo.java 810 2008-06-26 06:54:16Z maxberger $ */
+/* $Id: Mo.java 902 2009-03-20 11:32:25Z maxberger $ */
 
 package net.sourceforge.jeuclid.elements.presentation.token;
 
@@ -54,7 +54,7 @@ import org.w3c.dom.mathml.MathMLUnderOverElement;
 /**
  * This class presents a math operator, like "(" or "*".
  * 
- * @version $Revision: 810 $
+ * @version $Revision: 902 $
  */
 
 // CHECKSTYLE:OFF
@@ -563,8 +563,9 @@ public final class Mo extends AbstractJEuclidElement implements
         final float calcBaselineShift;
         final boolean stretchVertically = this.isVerticalDelimeter();
         JEuclidElement parent = this.getParent();
-        while (((parent instanceof MathMLUnderOverElement) && stretchVertically)
-                || ((parent instanceof Mrow) && (parent.getMathElementCount() == 1))) {
+        while ((((parent instanceof MathMLUnderOverElement) && stretchVertically) || ((parent instanceof Mrow) && (parent
+                .getMathElementCount() == 1)))
+                && (parent.getParent() != null)) {
             parent = parent.getParent();
         }
         final LayoutInfo parentInfo = view.getInfo(parent);
